@@ -1,5 +1,5 @@
 /****************************************************************************
- * examples/nxterm/nxterm_main.c
+ * apps/examples/nxterm/nxterm_main.c
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -34,6 +34,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include <string.h>
+#include <assert.h>
 #include <errno.h>
 #include <debug.h>
 
