@@ -66,11 +66,11 @@ int netlib_get_ipv4netmask(FAR const char *ifname, FAR struct in_addr *addr)
 
   if (ifname && addr)
     {
-      int sockfd = socket(PF_INET, NETLIB_SOCK_TYPE, 0);
+      int sockfd = socket(NET_SOCK_FAMILY, NET_SOCK_TYPE, NET_SOCK_PROTOCOL);
       if (sockfd >= 0)
         {
           struct ifreq req;
-          strncpy(req.ifr_name, ifname, IFNAMSIZ);
+          strlcpy(req.ifr_name, ifname, IFNAMSIZ);
           ret = ioctl(sockfd, SIOCGIFNETMASK, (unsigned long)&req);
           if (!ret)
             {
