@@ -62,7 +62,7 @@ int netlib_set_ipv6netmask(FAR const char *ifname,
 
   if (ifname && addr)
     {
-      int sockfd = socket(PF_INET6, NETLIB_SOCK_TYPE, 0);
+      int sockfd = socket(NET_SOCK_FAMILY, NET_SOCK_TYPE, NET_SOCK_PROTOCOL);
       if (sockfd >= 0)
         {
           FAR struct sockaddr_in6 *inaddr;
@@ -70,7 +70,7 @@ int netlib_set_ipv6netmask(FAR const char *ifname,
 
           /* Add the device name to the request */
 
-          strncpy(req.lifr_name, ifname, IFNAMSIZ);
+          strlcpy(req.lifr_name, ifname, IFNAMSIZ);
 
           /* Add the INET address to the request */
 
