@@ -1,5 +1,5 @@
 /****************************************************************************
- * netutils/thttpd/thttpd.c
+ * apps/netutils/thttpd/thttpd.c
  * Tiny HTTP Server
  *
  *   Copyright (C) 2009, 2011 Gregory Nutt. All rights reserved.
@@ -7,8 +7,8 @@
  *
  * Derived from the file of the same name in the original THTTPD package:
  *
- *   Copyright  1995,1998,1999,2000,2001 by Jef Poskanzer <jef@mail.acme.com>.
- *   All rights reserved.
+ *   Copyright (C) 1995,1998,1999,2000,2001 by
+ *   Jef Poskanzer <jef@mail.acme.com>. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -44,6 +44,7 @@
 #include <sys/time.h>
 
 #include <stdbool.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -84,7 +85,7 @@
 #define CNST_LINGERING 3
 
 #define SPARE_FDS      2
-#define AVAILABLE_FDS  (CONFIG_NSOCKET_DESCRIPTORS - SPARE_FDS)
+#define AVAILABLE_FDS  (CONFIG_THTTPD_NFILE_DESCRIPTORS - SPARE_FDS)
 
 /****************************************************************************
  * Private Types
@@ -129,7 +130,8 @@ static void finish_connection(struct connect_s *conn, struct timeval *tv);
 static void clear_connection(struct connect_s *conn, struct timeval *tv);
 static void really_clear_connection(struct connect_s *conn);
 static void idle(ClientData client_data, struct timeval *nowP);
-static void linger_clear_connection(ClientData client_data, struct timeval *nowP);
+static void linger_clear_connection(ClientData client_data,
+                                    struct timeval *nowP);
 static void occasional(ClientData client_data, struct timeval *nowP);
 
 /****************************************************************************
@@ -163,6 +165,7 @@ static void shut_down(void)
         {
           fdwatch_del_fd(fw, ths->listen_fd);
         }
+
       httpd_terminate(ths);
     }
 
@@ -179,7 +182,7 @@ static int handle_newconnect(FAR struct timeval *tv, int listen_fd)
    */
 
   ninfo("New connection(s) on listen_fd %d\n", listen_fd);
-  for (;;)
+  for (; ; )
     {
       /* Get the next free connection from the free list */
 
@@ -269,12 +272,15 @@ static void handle_read(struct connect_s *conn, struct timeval *tv)
           BADREQUEST("MAXREALLOC");
           goto errout_with_400;
         }
-      httpd_realloc_str(&hc->read_buf, &hc->read_size, hc->read_size + CONFIG_THTTPD_REALLOCINCR);
+
+      httpd_realloc_str(&hc->read_buf, &hc->read_size,
+                        hc->read_size + CONFIG_THTTPD_REALLOCINCR);
     }
 
   /* Read some more bytes */
 
-  sz = read(hc->conn_fd, &(hc->read_buf[hc->read_idx]), hc->read_size - hc->read_idx);
+  sz = read(hc->conn_fd, &(hc->read_buf[hc->read_idx]),
+            hc->read_size - hc->read_idx);
   if (sz == 0)
     {
       BADREQUEST("EOF");
@@ -372,8 +378,8 @@ static void handle_read(struct connect_s *conn, struct timeval *tv)
   actual = lseek(hc->file_fd, conn->offset, SEEK_SET);
   if (actual != conn->offset)
     {
-       nerr("ERROR: fseek to %d failed: offset=%d errno=%d\n",
-            conn->offset, actual, errno);
+       nerr("ERROR: fseek to %jd failed: offset=%jd errno=%d\n",
+            (intmax_t)conn->offset, (intmax_t)actual, errno);
        BADREQUEST("lseek");
        goto errout_with_400;
     }
@@ -414,6 +420,7 @@ static inline int read_buffer(struct connect_s *conn)
           hc->buflen      += nread;
         }
     }
+
   return nread;
 }
 
@@ -427,8 +434,10 @@ static void handle_send(struct connect_s *conn, struct timeval *tv)
 
   while (conn->offset < conn->end_offset)
     {
-      ninfo("offset: %d end_offset: %d bytes_sent: %d\n",
-            conn->offset, conn->end_offset, conn->hc->bytes_sent);
+      ninfo("offset: %jd end_offset: %jd bytes_sent: %jd\n",
+            (intmax_t)conn->offset,
+            (intmax_t)conn->end_offset,
+            (intmax_t)conn->hc->bytes_sent);
 
       /* Fill the rest of the response buffer with file data */
 
@@ -438,6 +447,7 @@ static void handle_send(struct connect_s *conn, struct timeval *tv)
           nerr("ERROR: File read error: %d\n", errno);
           goto errout_clear_connection;
         }
+
       ninfo("Read %d bytes, buflen %d\n", nread, hc->buflen);
 
       /* Send the buffer */
@@ -488,7 +498,7 @@ static void handle_linger(struct connect_s *conn, struct timeval *tv)
   httpd_conn *hc = conn->hc;
   int ret;
 
-    /* In lingering-close mode we just read and ignore bytes.  An error or EOF
+  /* In lingering-close mode we just read and ignore bytes.  An error or EOF
    * ends things, otherwise we go until a timeout
    */
 
@@ -552,7 +562,8 @@ static void clear_connection(struct connect_s *conn, struct timeval *tv)
       fdwatch_add_fd(fw, conn->hc->conn_fd, conn);
       client_data.p = conn;
 
-      conn->linger_timer = tmr_create(tv, linger_clear_connection, client_data,
+      conn->linger_timer = tmr_create(tv, linger_clear_connection,
+                                      client_data,
                                       CONFIG_THTTPD_LINGER_MSEC, 0);
       if (conn->linger_timer != NULL)
         {
@@ -562,7 +573,9 @@ static void clear_connection(struct connect_s *conn, struct timeval *tv)
       nerr("ERROR: tmr_create(linger_clear_connection) failed\n");
     }
 
-  /* Either we are done lingering, we shouldn't linger, or we failed to setup the linger */
+  /* Either we are done lingering, we shouldn't linger, or we failed to
+   * setup the linger
+   */
 
   really_clear_connection(conn);
 }
@@ -595,7 +608,8 @@ static void idle(ClientData client_data, struct timeval *nowP)
       switch (conn->conn_state)
         {
         case CNST_READING:
-          if (nowP->tv_sec - conn->active_at >= CONFIG_THTTPD_IDLE_READ_LIMIT_SEC)
+          if (nowP->tv_sec - conn->active_at >=
+              CONFIG_THTTPD_IDLE_READ_LIMIT_SEC)
             {
               nerr("ERROR: %s connection timed out reading\n",
                    httpd_ntoa(&conn->hc->client_addr));
@@ -606,7 +620,8 @@ static void idle(ClientData client_data, struct timeval *nowP)
           break;
 
         case CNST_SENDING:
-          if (nowP->tv_sec - conn->active_at >= CONFIG_THTTPD_IDLE_SEND_LIMIT_SEC)
+          if (nowP->tv_sec - conn->active_at >=
+              CONFIG_THTTPD_IDLE_SEND_LIMIT_SEC)
             {
               nerr("ERROR: %s connection timed out sending\n",
                    httpd_ntoa(&conn->hc->client_addr));
@@ -617,7 +632,8 @@ static void idle(ClientData client_data, struct timeval *nowP)
     }
 }
 
-static void linger_clear_connection(ClientData client_data, struct timeval *nowP)
+static void linger_clear_connection(ClientData client_data,
+                                    struct timeval *nowP)
 {
   struct connect_s *conn;
 
@@ -680,7 +696,7 @@ int thttpd_main(int argc, char **argv)
    * socket descriptors
    */
 
-  fw = fdwatch_initialize(CONFIG_NSOCKET_DESCRIPTORS);
+  fw = fdwatch_initialize(CONFIG_THTTPD_NFILE_DESCRIPTORS);
   if (!fw)
     {
       nerr("ERROR: fdwatch initialization failure\n");
@@ -714,7 +730,8 @@ int thttpd_main(int argc, char **argv)
 
   /* Set up the occasional timer */
 
-  if (tmr_create(NULL, occasional, JunkClientData, CONFIG_THTTPD_OCCASIONAL_MSEC * 1000L, 1) == NULL)
+  if (tmr_create(NULL, occasional, JunkClientData,
+      CONFIG_THTTPD_OCCASIONAL_MSEC * 1000L, 1) == NULL)
     {
       nerr("ERROR: tmr_create(occasional) failed\n");
       exit(1);
@@ -726,7 +743,6 @@ int thttpd_main(int argc, char **argv)
     {
       nerr("ERROR: tmr_create(idle) failed\n");
       exit(1);
-
     }
 
   /* Initialize our connections table */
@@ -745,8 +761,8 @@ int thttpd_main(int argc, char **argv)
       connects[cnum].hc          = NULL;
     }
 
-  connects[AVAILABLE_FDS-1].next = NULL;      /* End of link list */
-  free_connections               = connects;  /* Beginning of the link list */
+  connects[AVAILABLE_FDS - 1].next = NULL;      /* End of link list */
+  free_connections                 = connects;  /* Beginning of the link list */
 
   if (hs != NULL)
     {
@@ -760,7 +776,7 @@ int thttpd_main(int argc, char **argv)
 
   ninfo("Entering the main loop\n");
   gettimeofday(&tv, NULL);
-  for (;;)
+  for (; ; )
     {
       /* Do the fd watch */
 
@@ -805,7 +821,8 @@ int thttpd_main(int argc, char **argv)
 
       /* Find the connections that need servicing */
 
-      while ((conn = (struct connect_s*)fdwatch_get_next_client_data(fw)) != (struct connect_s*)-1)
+      while ((conn = (struct connect_s *)fdwatch_get_next_client_data(fw))
+             != (struct connect_s *)-1)
         {
           if (conn)
             {
@@ -819,8 +836,9 @@ int thttpd_main(int argc, char **argv)
                         {
                           handle_read(conn, &tv);
 
-                          /* If a GET request was received and a file is ready to
-                           * be sent, then fall through to send the file.
+                          /* If a GET request was received and a file is
+                           * ready to be sent, then fall through to send
+                           * the file.
                            */
 
                           if (conn->conn_state != CNST_SENDING)
@@ -831,9 +849,9 @@ int thttpd_main(int argc, char **argv)
 
                       case CNST_SENDING:
                         {
-                          /* Send a file -- this really should be performed on a
-                           * separate thread to keep the serve from locking up during
-                           * the write.
+                          /* Send a file -- this really should be performed
+                           * on a separate thread to keep the serve from
+                           * locking up during the write.
                            */
 
                           handle_send(conn, &tv);
@@ -851,6 +869,7 @@ int thttpd_main(int argc, char **argv)
                 }
             }
         }
+
       tmr_run(&tv);
     }
 
