@@ -1,5 +1,5 @@
 /************************************************************************************
- * apps/system/note/note_main.c
+ * apps/system/sched_note/note_main.c
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -60,6 +60,7 @@ static uint8_t g_note_buffer[CONFIG_SYSTEM_NOTE_BUFFERSIZE];
 
 /* Names of task/thread states */
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
 static FAR const char *g_statenames[] =
 {
   "Invalid",
@@ -76,6 +77,7 @@ static FAR const char *g_statenames[] =
 };
 
 #define NSTATES (sizeof(g_statenames)/sizeof(FAR const char *))
+#endif
 
 /************************************************************************************
  * Private Functions
@@ -128,8 +130,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length < sizeof(struct note_start_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: note too small for start note: %d\n",
+                  syslog(LOG_ERR,
+                         "Note too small for \"Start\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -168,8 +170,8 @@ static void dump_notes(size_t nread)
             {
               if (note->nc_length != sizeof(struct note_stop_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for stop note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"Stop\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -188,6 +190,7 @@ static void dump_notes(size_t nread)
             }
             break;
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
           case NOTE_SUSPEND:
             {
               FAR struct note_suspend_s *note_suspend =
@@ -196,8 +199,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_suspend_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for suspend note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"Suspend\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -230,8 +233,8 @@ static void dump_notes(size_t nread)
             {
               if (note->nc_length != sizeof(struct note_resume_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for resume note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"Resume\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -250,6 +253,7 @@ static void dump_notes(size_t nread)
 #endif
             }
             break;
+#endif
 
 #ifdef CONFIG_SMP
           case NOTE_CPU_START:
@@ -259,8 +263,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_cpu_start_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for CPU start note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"CPU Start\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -278,8 +282,8 @@ static void dump_notes(size_t nread)
             {
               if (note->nc_length != sizeof(struct note_cpu_started_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for CPU started note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"CPU started\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -292,6 +296,7 @@ static void dump_notes(size_t nread)
             }
             break;
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_SWITCH
           case NOTE_CPU_PAUSE:
             {
               FAR struct note_cpu_pause_s *note_pause =
@@ -299,8 +304,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_cpu_pause_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for CPU pause note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"CPU pause\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -318,8 +323,8 @@ static void dump_notes(size_t nread)
             {
               if (note->nc_length != sizeof(struct note_cpu_paused_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for CPU paused note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"CPU paused\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -339,8 +344,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_cpu_resume_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for CPU resume note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"CPU resume\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -358,8 +363,8 @@ static void dump_notes(size_t nread)
             {
               if (note->nc_length != sizeof(struct note_cpu_resumed_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for CPU resumed note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"CPU resumed\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -372,6 +377,7 @@ static void dump_notes(size_t nread)
             }
             break;
 #endif
+#endif
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_PREEMPTION
           case NOTE_PREEMPT_LOCK:
@@ -383,8 +389,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_preempt_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for preemption note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"Preemption\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -439,8 +445,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_csection_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for csection note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"csection\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -497,8 +503,8 @@ static void dump_notes(size_t nread)
 
               if (note->nc_length != sizeof(struct note_spinlock_s))
                 {
-                  syslog(LOG_INFO,
-                         "ERROR: Size incorrect for spinlock note: %d\n",
+                  syslog(LOG_ERR,
+                         "Size incorrect for \"Spinlock\" note: %d\n",
                          note->nc_length);
                   return;
                 }
@@ -633,8 +639,8 @@ static void dump_notes(size_t nread)
 
                     if (note->nc_length < SIZEOF_NOTE_SYSCALL_ENTER(0))
                       {
-                        syslog(LOG_INFO,
-                               "ERROR: Size incorrect for SYSCALL enter note: %d\n",
+                        syslog(LOG_ERR,
+                               "Size incorrect for \"SYSCALL enter\" note: %d\n",
                                note->nc_length);
                         return;
                       }
@@ -654,8 +660,8 @@ static void dump_notes(size_t nread)
 
                     if (note->nc_length != sizeof(struct note_syscall_leave_s))
                       {
-                        syslog(LOG_INFO,
-                               "ERROR: Size incorrect for SYSCALL leave note: %d\n",
+                        syslog(LOG_ERR,
+                               "Size incorrect for \"SYSCALL leave\" note: %d\n",
                                note->nc_length);
                         return;
                       }
@@ -691,8 +697,8 @@ static void dump_notes(size_t nread)
 
                     if (note->nc_length != sizeof(struct note_irqhandler_s))
                       {
-                        syslog(LOG_INFO,
-                               "ERROR: Size incorrect for IRQ note: %d\n",
+                        syslog(LOG_ERR,
+                               "Size incorrect for \"IRQ\" note: %d\n",
                                note->nc_length);
                         return;
                       }
@@ -706,6 +712,68 @@ static void dump_notes(size_t nread)
                   break;
 #endif
 
+#ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
+                case NOTE_DUMP_STRING:
+                  {
+                    FAR struct note_string_s *note_string =
+                      (FAR struct note_string_s *)note;
+
+                    if (note->nc_length < sizeof(struct note_string_s))
+                      {
+                        syslog(LOG_INFO,
+                               "ERROR: note too small for string note: %d\n",
+                               note->nc_length);
+                        return;
+                      }
+
+                    syslog_time(LOG_INFO,
+                           "Task %u priority %u, string:%s\n",
+                           (unsigned int)pid,
+                           (unsigned int)note->nc_priority,
+                           note_string->nst_data);
+                  }
+                  break;
+
+                case NOTE_DUMP_BINARY:
+                  {
+                    FAR struct note_binary_s *note_binary =
+                      (FAR struct note_binary_s *)note;
+                    char out[1280];
+                    int count;
+                    int ret = 0;
+                    int i;
+
+                    count = note->nc_length - sizeof(struct note_binary_s) + 1;
+
+                    if (count < 0)
+                      {
+                        syslog(LOG_INFO,
+                               "ERROR: note too small for binary note: %d\n",
+                               note->nc_length);
+                        return;
+                      }
+
+                    for (i = 0; i < count; i++)
+                      {
+                        ret += sprintf(&out[ret], " 0x%x", note_binary->nbi_data[i]);
+                      }
+
+                    syslog_time(LOG_INFO,
+                           "Task %u priority %u, binary:module=%c%c%c%c "
+                            "event=%u count=%u%s\n",
+                           (unsigned int)pid,
+                           (unsigned int)note->nc_priority,
+                           note_binary->nbi_module[0],
+                           note_binary->nbi_module[1],
+                           note_binary->nbi_module[2],
+                           note_binary->nbi_module[3],
+                           note_binary->nbi_event,
+                           count,
+                           out);
+                  }
+                  break;
+#endif
+
           default:
             syslog(LOG_INFO, "Unrecognized note type: %d\n", note->nc_type);
             return;
@@ -736,7 +804,7 @@ static int note_daemon(int argc, char *argv[])
   if (fd < 0)
     {
       int errcode = errno;
-      syslog(LOG_INFO, "note_daemon: ERROR: Failed to open /dev/note: %d\n",
+      syslog(LOG_ERR, "note_daemon: ERROR: Failed to open /dev/note: %d\n",
              errcode);
       goto errout;
     }
