@@ -91,7 +91,6 @@ struct fstest_filedesc_s
   bool failed;
   size_t len;
   uint32_t crc;
-  uint32_t hash;
 };
 
 /****************************************************************************
@@ -107,7 +106,6 @@ static char g_mountdir[CONFIG_TESTING_FSTEST_MAXNAME] =
 static int g_nfiles;
 static int g_ndeleted;
 static int g_nfailed;
-static bool g_media_full;
 
 static struct mallinfo g_mmbefore;
 static struct mallinfo g_mmprevious;
@@ -124,13 +122,18 @@ static struct mallinfo g_mmafter;
 static void fstest_showmemusage(struct mallinfo *mmbefore,
                                 struct mallinfo *mmafter)
 {
-  printf("VARIABLE  BEFORE   AFTER\n");
-  printf("======== ======== ========\n");
-  printf("arena    %8x %8x\n", mmbefore->arena,    mmafter->arena);
-  printf("ordblks  %8d %8d\n", mmbefore->ordblks,  mmafter->ordblks);
-  printf("mxordblk %8x %8x\n", mmbefore->mxordblk, mmafter->mxordblk);
-  printf("uordblks %8x %8x\n", mmbefore->uordblks, mmafter->uordblks);
-  printf("fordblks %8x %8x\n", mmbefore->fordblks, mmafter->fordblks);
+  printf("VARIABLE  BEFORE   AFTER    DELTA\n");
+  printf("======== ======== ======== ========\n");
+  printf("arena    %8x %8x %8x\n", mmbefore->arena   , mmafter->arena,
+                                   mmafter->arena    - mmbefore->arena);
+  printf("ordblks  %8d %8d %8d\n", mmbefore->ordblks , mmafter->ordblks,
+                                   mmafter->ordblks  - mmbefore->ordblks);
+  printf("mxordblk %8x %8x %8x\n", mmbefore->mxordblk, mmafter->mxordblk,
+                                   mmafter->mxordblk - mmbefore->mxordblk);
+  printf("uordblks %8x %8x %8x\n", mmbefore->uordblks, mmafter->uordblks,
+                                   mmafter->uordblks - mmbefore->uordblks);
+  printf("fordblks %8x %8x %8x\n", mmbefore->fordblks, mmafter->fordblks,
+                                   mmafter->fordblks - mmbefore->fordblks);
 }
 
 /****************************************************************************
@@ -191,19 +194,18 @@ static inline char fstest_randchar(void)
 }
 
 /****************************************************************************
- * Name: fstest_checkexit
+ * Name: fstest_checkexist
  ****************************************************************************/
 
-static bool fstest_checkexit(FAR struct fstest_filedesc_s *file)
+static bool fstest_checkexist(FAR struct fstest_filedesc_s *file)
 {
   int i;
   bool ret = false;
 
   for (i = 0; i < CONFIG_TESTING_FSTEST_MAXOPEN; i++)
     {
-      if (!g_files[i].deleted &&
-          &g_files[i] != file &&
-          g_files[i].hash == file->hash)
+      if (&g_files[i] != file && g_files[i].name &&
+          strcmp(g_files[i].name, file->name) == 0)
         {
           ret = true;
           break;
@@ -251,10 +253,8 @@ static inline void fstest_randname(FAR struct fstest_filedesc_s *file)
         }
 
       file->name[alloclen] = '\0';
-      file->hash = crc32((const uint8_t *)file->name + dirlen,
-                         alloclen - dirlen);
     }
-  while (fstest_checkexit(file));
+  while (fstest_checkexist(file));
 }
 
 /****************************************************************************
@@ -456,11 +456,7 @@ static inline int fstest_wrfile(FAR struct fstest_filedesc_s *file)
             {
               continue;
             }
-          else if (errcode == ENOSPC)
-            {
-              g_media_full = true;
-            }
-          else
+          else if (errcode != ENOSPC)
             {
               printf("ERROR: Failed to write file: %d\n", errcode);
               printf("  File name:    %s\n", file->name);
@@ -517,8 +513,6 @@ static int fstest_fillfs(void)
 
   /* Create a file for each unused file structure */
 
-  g_media_full = false;
-
   for (i = 0; i < CONFIG_TESTING_FSTEST_MAXOPEN; i++)
     {
       file = &g_files[i];
@@ -537,11 +531,6 @@ static int fstest_fillfs(void)
           printf("  Created file %s\n", file->name);
 #endif
           g_nfiles++;
-
-          if (g_media_full)
-            {
-              break;
-            }
         }
     }
 
@@ -666,7 +655,7 @@ static inline int fstest_rdfile(FAR struct fstest_filedesc_s *file)
 
   /* Try reading past the end of the file */
 
-  nbytesread = fstest_rdblock(fd, file, ntotalread, 1024) ;
+  nbytesread = fstest_rdblock(fd, file, ntotalread, 1024);
   if (nbytesread > 0)
     {
       printf("ERROR: Read past the end of file\n");
@@ -910,6 +899,7 @@ static int fstest_delallfiles(void)
     }
 
   g_nfiles = 0;
+  g_nfailed = 0;
   g_ndeleted = 0;
   return OK;
 }
@@ -969,7 +959,7 @@ static void show_useage(void)
   printf("Usage : fstest [OPTION [ARG]] ...\n");
   printf("-h    show this help statement\n");
   printf("-n    num of test loop e.g. [%d]\n", CONFIG_TESTING_FSTEST_NLOOPS);
-  printf("-m    mount point tobe test e.g. [%s]\n",
+  printf("-m    mount point to be tested e.g. [%s]\n",
           CONFIG_TESTING_FSTEST_MOUNTPT);
 }
 
