@@ -1,35 +1,20 @@
 /****************************************************************************
  * apps/testing/mm/mm_main.c
  *
- *   Copyright (C) 2011, 2020 Gregory Nutt. All rights reserved.
- *   Author: Gregory Nutt <gnutt@nuttx.org>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -74,18 +59,18 @@
 
 static const int g_alloc_sizes[NTEST_ALLOCS] =
 {
-   1024,     12,    962,   5692, 10254,   111,   9932,    601,
+    1024,    12,    962,   5692, 10254,   111,   9932,    601,
     222,   2746,      3, 124321,    68,   776,   6750,    852,
-   4732,     28,    901,    480,  5011,  1536,   2011,  81647,
+    4732,    28,    901,    480,  5011,  1536,   2011,  81647,
     646,   1646,  69179,    194,  2590,     7,    969,     70
 };
 
 static const int g_realloc_sizes[NTEST_ALLOCS] =
 {
-     18,   3088,    963,    123,   511, 11666,   3723,     42,
-   9374,   1990,   1412,      6,   592,  4088,     11,   5040,
-   8663,  91255,     28,   4346,  9172,   168,    229,   4734,
-  59139,    221,   7830,  30421,  1666,     4,    812,    416
+    18,     3088,    963,    123,   511, 11666,   3723,     42,
+    9374,   1990,   1412,      6,   592,  4088,     11,   5040,
+    8663,  91255,     28,   4346,  9172,   168,    229,   4734,
+    59139,   221,   7830,  30421,  1666,     4,    812,    416
 };
 
 static const int g_random1[NTEST_ALLOCS] =
@@ -166,7 +151,8 @@ static void do_mallocs(FAR void **mem, FAR const int *size,
 
               if (allocsize > g_alloc_info.mxordblk)
                 {
-                  fprintf(stderr, "   Normal, largest free block is only %lu\n",
+                  fprintf(stderr,
+                          "   Normal, largest free block is only %lu\n",
                           (unsigned long)g_alloc_info.mxordblk);
                 }
               else
@@ -205,7 +191,8 @@ static void do_reallocs(FAR void **mem, FAR const int *oldsize,
         {
           int allocsize = MM_ALIGN_UP(newsize[j] + SIZEOF_MM_ALLOCNODE);
 
-          fprintf(stderr, "(%d)realloc failed for allocsize=%d\n", i, allocsize);
+          fprintf(stderr,
+                  "(%d)realloc failed for allocsize=%d\n", i, allocsize);
           if (allocsize > g_alloc_info.mxordblk)
             {
               fprintf(stderr, "   Normal, largest free block is only %lu\n",
@@ -227,7 +214,9 @@ static void do_reallocs(FAR void **mem, FAR const int *oldsize,
     }
 }
 
-static void do_memaligns(FAR void **mem, FAR const int *size, FAR const int *align,
+static void do_memaligns(FAR void **mem,
+                         FAR const int *size,
+                         FAR const int *align,
                          FAR const int *seq, int n)
 {
   int i;
@@ -244,9 +233,11 @@ static void do_memaligns(FAR void **mem, FAR const int *size, FAR const int *ali
 
       if (mem[j] == NULL)
         {
-          int allocsize = MM_ALIGN_UP(size[j] + SIZEOF_MM_ALLOCNODE) + 2*align[i];
+          int allocsize = MM_ALIGN_UP(size[j] + SIZEOF_MM_ALLOCNODE) +
+                                      2 * align[i];
 
-          fprintf(stderr, "(%d)memalign failed for allocsize=%d\n", i, allocsize);
+          fprintf(stderr,
+                  "(%d)memalign failed for allocsize=%d\n", i, allocsize);
           if (allocsize > g_alloc_info.mxordblk)
             {
               fprintf(stderr, "   Normal, largest free block is only %lu\n",
@@ -306,7 +297,8 @@ int main(int argc, FAR char *argv[])
 
   /* Re-allocate the memory */
 
-  do_reallocs(g_allocs, g_alloc_sizes, g_realloc_sizes, g_random2, NTEST_ALLOCS);
+  do_reallocs(g_allocs, g_alloc_sizes,
+              g_realloc_sizes, g_random2, NTEST_ALLOCS);
 
   /* Release the memory */
 
@@ -314,8 +306,10 @@ int main(int argc, FAR char *argv[])
 
   /* Allocate aligned memory */
 
-  do_memaligns(g_allocs, g_alloc_sizes, g_alignment, g_random2, NTEST_ALLOCS / 2);
-  do_memaligns(g_allocs, g_alloc_sizes, g_alignment, &g_random2[NTEST_ALLOCS / 2],
+  do_memaligns(g_allocs, g_alloc_sizes,
+               g_alignment, g_random2, NTEST_ALLOCS / 2);
+  do_memaligns(g_allocs, g_alloc_sizes,
+               g_alignment, &g_random2[NTEST_ALLOCS / 2],
                NTEST_ALLOCS / 2);
 
   /* Release aligned memory */
