@@ -31,9 +31,9 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifndef NULL
-# define NULL (void*)0
-#endif
+/****************************************************************************
+ * Private Types
+ ****************************************************************************/
 
 static volatile enum
 {
@@ -42,6 +42,10 @@ static volatile enum
   COND_WAIT
 } waiter_state;
 
+/****************************************************************************
+ * Private Data
+ ****************************************************************************/
+
 static pthread_mutex_t mutex;
 static pthread_cond_t  cond;
 static volatile int data_available = 0;
@@ -54,7 +58,7 @@ static int signaler_state = 0;
 static int signaler_nerrors = 0;
 
 /****************************************************************************
- * Public Functions
+ * Private Functions
  ****************************************************************************/
 
 static void *thread_waiter(void *parameter)
@@ -215,6 +219,10 @@ static void *thread_signaler(void *parameter)
   return NULL; /* Non-reachable -- needed for some compilers */
 }
 
+/****************************************************************************
+ * Public Functions
+ ****************************************************************************/
+
 void cond_test(void)
 {
   pthread_t waiter;
