@@ -30,10 +30,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifndef NULL
-# define NULL (void*)0
-#endif
-
 #define NLOOPS 32
 
 /****************************************************************************
