@@ -40,10 +40,6 @@
 #define SEM1_NAME "foo"
 #define SEM2_NAME "bar"
 
-#ifndef NULL
-# define NULL (void*)0
-#endif
-
 /****************************************************************************
  * Private Data
  ****************************************************************************/
