@@ -35,10 +35,6 @@
  * Preprocessor Definitions
  ****************************************************************************/
 
-#ifndef NULL
-# error Broken toolchain does not have NULL
-#endif
-
 /****************************************************************************
  * Private Data
  ****************************************************************************/
