@@ -34,14 +34,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#ifndef NULL
-# define NULL (void*)0
-#endif
-
-#ifndef OK
-# define OK 0
-#endif
-
 /****************************************************************************
  * Private Data
  ****************************************************************************/
