@@ -365,6 +365,10 @@ static int wapi_scan_event(FAR struct iw_event *event,
               {
                 info->freq = 2484;
               }
+            else if (event->u.freq.m >= 36 && event->u.freq.m <= 165)
+              {
+                info->freq = 5000 + 5 * event->u.freq.m;
+              }
           }
         else
           {
@@ -475,11 +479,11 @@ int wapi_get_freq(int sock, FAR const char *ifname, FAR double *freq,
     {
       /* Set flag. */
 
-      if (IW_FREQ_AUTO == (wrq.u.freq.flags & IW_FREQ_AUTO))
+      if (IW_FREQ_AUTO == wrq.u.freq.flags)
         {
           *flag = WAPI_FREQ_AUTO;
         }
-      else if (IW_FREQ_FIXED == (wrq.u.freq.flags & IW_FREQ_FIXED))
+      else if (IW_FREQ_FIXED == wrq.u.freq.flags)
         {
           *flag = WAPI_FREQ_FIXED;
         }
